/**
*  IRS-III
*  http://kmi.open.ac.uk/projects/irs
*
*  KMI - Knowledge Media Institute
*  The Open University
*
*  Written by: Liliana Cabral
*
*  This is a test application for IRS-III.
*  It shows how to handle Goal, WebService and Mediator descriptions and Ontologies.
*
*/

import kmi.irsIII.*;
import kmi.irsIII.wsmo.*;
import kmi.irsIII.wsmo.WebServiceDescription.*;
import kmi.irsIII.wsmo.GoalDescription.*;
import kmi.irsIII.wsmo.MediatorDescription.*;
import kmi.irsIII.wsmo.OntologyDescription.*;


import java.util.*;


class TestIRSIIIa {
	static public void main (String args[]) {
	String IRSServerURL = "http://anfield.open.ac.uk:3000/soap";

	try {

//
// Connecting to IRS-III
//
//

		IRSIIIServer irsServer = new IRSIIIServer(IRSServerURL, "wsmo", "wsmo");



		ArrayList goalInputRoles1 = new ArrayList();

		// args: name, type, soapType

		goalInputRoles1.add(new GoalRole("has_source_currency", "currency", "sexpr"));
		goalInputRoles1.add(new GoalRole("has_target_currency", "currency", "sexpr"));
		//goalInputRoles.add(new GoalRole("has_amount", "positive-number", "float"));


		GoalRole goalOutputRole1 = new GoalRole("has_exchange","positive-number","float");


		Goal goal1 = new Goal(new WSNonFunctionalProperties("exchange-rate-mediation-service-wsmo","wsmo-guest-goals"),
							goalInputRoles1, //java.util.Collection inputRoles,
							goalOutputRole1, //GoalRole outputRole)
            				null, //goalUsedMediators, //java.util.Collection goalUsedMediators,
            				null,  //; PostCondition postCondition,
            				null, //Effect effect);
            				null); //parent
// saveGoalDescription
		String reply3 = irsServer.saveGoalDescription(goal1);
		System.out.println(" saveGoalDescription exchange-rate-mediation-service-wsmo Response: " + reply3);





//
// Creating/editing ServiceDescription
//
//

		ArrayList inputWSRoles = new ArrayList();

		// args: name, type, soapType

		inputWSRoles.add(new WSRole("has_source_currency", "currency"));
		inputWSRoles.add(new WSRole("has_target_currency", "currency"));


		WSRole outputWSRole = new WSRole("exchange-rate","integer");



		ArrayList usedMediators = new ArrayList();
		OOMediator ooMediator = new OOMediator(
						new WSNonFunctionalProperties("exchange-rate-oo-mediator-wsmo","wsmo-guest-web-services"),
						new Ontology(new NonFunctionalProperties("ontology-source-wsmo","wsmo-guest-web-services"),null, null, null,null,null),
						new Ontology(new NonFunctionalProperties("ontology-target-wsmo","wsmo-guest-web-services"),null, null, null,null,null),
						new Goal(new NonFunctionalProperties("exchange-rate-mediation-service-wsmo","wsmo-guest-goals"),null, null, null,null,null,null)); //MediationService mediationService,);

		usedMediators.add(ooMediator);

		ArrayList capUsedMediators = new ArrayList();


		WGMediator wgMediator = new WGMediator(new WSNonFunctionalProperties("exchange-rate-wg-mediator-wsmo","wsmo-guest-web-services"),
					new WebService(new WSNonFunctionalProperties("exchange-rate-goal-wsmo","wsmo-guest-goals"),null, null,null,null,null,null), //WGSource sourceComponent,
					null, //new Goal(new NonFunctionalProperties("exchange-rate-goal-wsmo","wsmo-guest-goals"),null, null, null,null,null,null), //WGTarget targetComponent,
					null, //new Goal(new NonFunctionalProperties("exchange-rate-mediation-service-wsmo","wsmo-guest-goals"),null, null, null,null,null,null), //MediationService mediationService,
					null, //Collection usedMediators,
					null); //Reduction reduction)

		capUsedMediators.add(wgMediator);


		ServiceCapability servCapab = new ServiceCapability(
						new NonFunctionalProperties("exchange-rate-capability-wsmo",null), // nonFunctionalProperties,
                         capUsedMediators, //java.util.Collection usedMediators,
                         null, // PreCondition preCondition,
                         null, //PostCondition postCondition,
                         null, //Assumption assumption,
                         null, //Effect effect)
                         null); //parent

		ServiceInterface servInter = new ServiceInterface(
						new NonFunctionalProperties("exchange-rate-interface-wsmo", null), // nonFunctionalProperties,
                        null, //java.util.Collection usedOOMediators,
                        new Choreography("choreography-wsmo",null), // choreography,
                        new Orchestration("orchestration-wsmo",null),
                        null); // parent)

		WebService webService = new WebService(
					new WSNonFunctionalProperties("exchange-rate-wsmo-ws","wsmo-guest-web-services"), // wsNonFunctionalProperties,
					inputWSRoles, //java.util.Collection inputWSRoles,
					outputWSRole, //WSRole outputWSRole,
                  	servCapab, //ServiceCapability serviceCapability,
                  	servInter, //ServiceInterface serviceInterface,
                  	null, //usedMediators, //java.util.Collection usedOOMediators);
                  	null); //parent;

		String reply4 = irsServer.saveWebServiceDescription(webService);

		System.out.println(" saveWebServiceDescription Response: " + reply4);

		String reply5 = irsServer.saveMediatorDescription(wgMediator);
		System.out.println(" saveWebServiceDescription Response: " + reply5);

		String reply6 = irsServer.saveMediatorDescription(ooMediator);
		System.out.println(" saveWebServiceDescription Response: " + reply6);



		//String reply25 = irsServer.saveCapabilityDescription(webService);
		//System.out.println(" saveCapabilityDescription Response: " + reply25);


	//	Mediator reply16 = irsServer.getMediatorDescription("exchange-rate-mediator","wsmo-exchange-rate");
	//	System.out.println(" getMediatorDescription Response: " + reply16);

	//	ServiceCapability reply15 = irsServer.getCapabilityDescription("exchange-rate-capability-wsmo","wsmo-guest-web-services");
	//	System.out.println(" getCapabilityDescription Response: " + reply15);

	//	ServiceCapability reply17 = irsServer.getCapabilityDescription("european-exchange-rate-capability","wsmo-exchange-rate");
	//	System.out.println(" getCapabilityDescription Response: " + reply17);




	//	String reply26 = irsServer.saveInterfaceDescription(webService);
	//	System.out.println(" saveInterfaceDescription Response: " + reply26);


//
// Creating/editing GoalDescription
//
//

		ArrayList goalInputRoles = new ArrayList();

		// args: name, type, soapType

		goalInputRoles.add(new GoalRole("has_source_currency", "currency", "sexpr"));
		goalInputRoles.add(new GoalRole("has_target_currency", "currency", "sexpr"));
		//goalInputRoles.add(new GoalRole("has_amount", "positive-number", "float"));


		GoalRole goalOutputRole = new GoalRole("has_exchange","positive-number","float");

		ArrayList goalUsedMediators = new ArrayList();
		OOMediator gooMediator = new OOMediator(
						new WSNonFunctionalProperties("exchange-rate-oo-mediator-wsmo",null),
						null, //new Ontology(new NonFunctionalProperties("ontology-source-wsmo","wsmo-guest-web-services"),null, null, null,null,null),
						null, //new Ontology(new NonFunctionalProperties("ontology-target-wsmo","wsmo-guest-web-services"),null, null, null,null,null),
						new Goal(new NonFunctionalProperties("exchange-rate-mediation-service-wsmo","wsmo-guest-goals"),null, null, null,null,null,null)); //MediationService mediationService,);
		goalUsedMediators.add(gooMediator);



		Goal goal = new Goal(new WSNonFunctionalProperties("exchange-rate-goal-wsmo","wsmo-guest-goals"),
							goalInputRoles, //java.util.Collection inputRoles,
							goalOutputRole, //GoalRole outputRole)
            				goalUsedMediators, //java.util.Collection goalUsedMediators,
            				null,  //; PostCondition postCondition,
            				null, //Effect effect);
            				null); //parent



// saveGoalDescription
		String reply23 = irsServer.saveGoalDescription(goal);
		System.out.println(" saveGoalDescription Response: " + reply23);

// getGoalDescription
		Goal goalReply = irsServer.getGoalDescription("exchange-rate-goal-wsmo", "wsmo-guest-goals");

		ArrayList inputGoalRoles = (ArrayList) goalReply.getInputGoalRoles();

		for(Iterator it = inputGoalRoles.iterator(); it.hasNext(); ){

			GoalRole goalRole = (GoalRole)it.next();
			System.out.println("Goal input name: " + goalRole.getName());
		}

// getWSDescription
		WebService wsReply = irsServer.getWSDescription("exchange-rate-wsmo-ws", "wsmo-guest-web-services");

		ArrayList inputWSRoles2 = (ArrayList) wsReply.getInputWSRoles();

		for(Iterator it = inputWSRoles2.iterator(); it.hasNext(); ){

			WSRole wsRole = (WSRole)it.next();
			System.out.println("Web Service input name: " + wsRole.getName());
		}

/*

//
// Creating Ontology
//
//

		try {
		System.out.println("Creating new ontology...");
		OntologyProperties ontologyProp1 = new OntologyProperties(
														"goal",  			//ontologyType
														"wsmo-guest-goals", 	//ontologyName
														"wsmo", 	//ontologyParents
														"guest", 			//allowedEditors
														"wsmo"); 			//ontologyAuthor
		String replyOntProp1 = irsServer.createOntology(ontologyProp1);
		System.out.println("createOntology wsmo-guest-goals Response: " + replyOntProp1);

		}catch(IRSIIIException e) {
			System.out.println("...From createOntology...: " + e.getMessage());
		}
//
// Getting Ontology Properties
//
//

		System.out.println("getOntologyProperties...");
		OntologyProperties ontologyPropResponse1 = irsServer.getOntologyProperties("wsmo-guest-goals");
		System.out.println("Get Ontology Response... ");
		System.out.println("Ontology Type: " + ontologyPropResponse1.getType());
		System.out.println("Ontology Name: " + ontologyPropResponse1.getName());
		System.out.println("Ontology Parents: " + ontologyPropResponse1.getParents());
		System.out.println("Ontology Editors: " + ontologyPropResponse1.getAllowedEditors());
		System.out.println("Ontology Author: " + ontologyPropResponse1.getAuthor());

//
// Creating Ontology
//
//
		OntologyProperties ontologyProp2=null;

		try {
		System.out.println("Creating new ontology...");
		ontologyProp2 = new OntologyProperties(
							"web-service",  			//ontologyType
							"wsmo-guest-web-services", 	//ontologyName
							"wsmo wsmo-guest-goals", 				//ontologyParents
							"guest", 			//allowedEditors
							"wsmo"); 			//ontologyAuthor
		String replyOntProp2 = irsServer.createOntology(ontologyProp2);
		System.out.println("createOntology wsmo-guest-web-services Response: " + replyOntProp2);

		}catch(IRSIIIException e) {
			System.out.println("...From createOntology...: " + e.getMessage());
		}
//
// Getting Ontology Properties
//
//

		System.out.println("getOntologyProperties...");
		OntologyProperties ontologyPropResponse2 = irsServer.getOntologyProperties("wsmo-guest-web-services");
		System.out.println("Get Ontology Response... ");
		System.out.println("Ontology Type: " + ontologyPropResponse2.getType());
		System.out.println("Ontology Name: " + ontologyPropResponse2.getName());
		System.out.println("Ontology Parents: " + ontologyPropResponse2.getParents());
		System.out.println("Ontology Editors: " + ontologyPropResponse2.getAllowedEditors());
		System.out.println("Ontology Author: " + ontologyPropResponse2.getAuthor());


		//System.out.println("Update ontology...");
		//OntologyProperties ontologyProp2 = new OntologyProperties(
		//												"goal",  				//ontologyType
		//												"wsmo-guest", 	//ontologyName
		//												"wsmo", 					//ontologyParents
		//												"guest liliana", 				//allowedEditors
		//												"wsmo"); 				//ontologyAuthor
//
		String replyOntProp2 = irsServer.updateOntologyProperties("wsmo-guest-web-services",ontologyProp2);
		System.out.println("updateOntologyProperties Response: " + replyOntProp2);


*/


	}catch(IRSIIIException e) {
		System.out.println("...From IRS Server...: " + e.getMessage());

	}catch(Exception e) {
		e.printStackTrace();
		System.out.println("TestApp Exception: " + e.toString());
	}


	}
}