/**
*  IRS-III
*  http://kmi.open.ac.uk/projects/irs
*
*  KMI - Knowledge Media Institute
*  The Open University
*
*  Written by: Liliana Cabral
*
*  This is a test application for IRS-III.
*  It shows how to handle publishing and invocation of services.
*
*/

import kmi.irsIII.*;
import kmi.irsIII.wsmo.*;
import kmi.irsIII.wsmo.WebServiceDescription.*;
import kmi.irsIII.wsmo.GoalDescription.*;
import kmi.irsIII.wsmo.MediatorDescription.*;
import kmi.irsIII.wsmo.OntologyDescription.*;

import java.util.*;


class TestIRSIIIb {
	static public void main (String args[]) {
	String IRSServerURL = "http://anfield.open.ac.uk:3000/soap";

	try {

///
// Connecting to IRS-III
//
///
		IRSIIIServer irsServer = new IRSIIIServer(IRSServerURL, "wsmo", "wsmo");




///
// Publishing a java Class
//
//
		System.out.println();
		System.out.println("Publishing a java class ...");
		System.out.println();

		String resp3 = irsServer.publishJavaClass("exchange-rate-wsmo-ws", //Name,
						 	"wsmo-guest-web-services", //Ontology,
						 	"KMIExchange",
						 	"exchangeRate",
					     	"http://anfield.open.ac.uk:8080/IRSPublisher/JavaClassRegister"); //webService_URL,

        System.out.println("publishJavaClass response: " + resp3);
/*

///
// Publishing Lisp function
//
//
		String resp = irsServer.publishLispFunction("exchange-rate-wsmo-ws", // webServiceName
											"wsmo-guest-web-services", //webServiceOntology
						 					"exchange-rate-provider-fun2", //functionName
					     					"http://anfield.open.ac.uk:3001/soap"); //lispPublisherURL

        System.out.println("publishLispFunction: " + resp);
*/

///
// Invoking
//
///
		System.out.println();
		System.out.println("Query: What's the exchange rate from pounds to euros?");
		System.out.println();

		ArrayList achieveGoalInputs = new ArrayList();

		achieveGoalInputs.add(new AchieveGoalInput("has_source_currency", "pound"));
		achieveGoalInputs.add(new AchieveGoalInput("has_target_currency", "euro"));


		Goal goal = new Goal(new NonFunctionalProperties("exchange-rate-goal-wsmo","wsmo-guest-goals"),
							null,
							null,
            				null, //goalUsedMediators, //java.util.Collection goalUsedMediators,
            				null,  //; PostCondition postCondition,
            				null, //Effect effect);
            				null); // parent


		String response6 = irsServer.achieveGoal(goal, achieveGoalInputs);

        System.out.println("achieveGoal exchange-rate-goal-wsmo: " + response6);








///
// Publishing a WSDL
//
//
		System.out.println();
		System.out.println("Publishing a WSDL ...");
		System.out.println();

		String resp5 = irsServer.publishWebServiceWSDL("test-ws", //Name,
                            "wsmo-test", //Ontology,
                            "getTemp", //operationName,
                            "TemperaturePortType", //portType,
                            "http://www.xmethods.net/sd/TemperatureService.wsdl", //targetNameSpace,
                            "http://www.xmethods.net/sd/2001/TemperatureService.wsdl", //WSDL_URL,
                            "APACHE_SOAP", //webServiceProviderType,
                            "http://anfield.open.ac.uk:8080/IRSPublisher/WSDLRegister"); //IRS_WSDL_PublisherURL)


        System.out.println("publishWebServiceWSDL response: " + resp5);


///
// Invoking
//
///
		System.out.println();
		System.out.println("Query: What's the temperature in the US city with Zipcode 15220?");
		System.out.println();




		ArrayList achieveGoalInputs2 = new ArrayList();

		achieveGoalInputs2.add(new AchieveGoalInput("input1", "15220"));


		Goal goal2 = new Goal(new NonFunctionalProperties("test-goal","wsmo-test"),
							null,
							null,
            				null, //goalUsedMediators, //java.util.Collection goalUsedMediators,
            				null,  //; PostCondition postCondition,
            				null, //Effect effect);
            				null); // parent


		String response7 = irsServer.achieveGoal(goal2, achieveGoalInputs2);

        System.out.println("achieveGoal test-goal: " + response7);





	}catch(IRSIIIException e) {
		System.out.println("...From IRS Server...: " + e.getMessage());

	}catch(Exception e) {
		//e.printStackTrace();
		System.out.println("TestApp Exception: " + e.toString());
	}


	}
}